@@ -1,5 +1,7 @@
 import os
 
+from matplotlib import pyplot as plt
+
 os.environ["OMP_NUM_THREADS"] = "10"  # export OMP_NUM_THREADS=4
 os.environ["OPENBLAS_NUM_THREADS"] = "10"  # export OPENBLAS_NUM_THREADS=4
 os.environ["MKL_NUM_THREADS"] = "10"  # export MKL_NUM_THREADS=6
@@ -44,18 +46,45 @@ def calcAffinityMatrix(*, pixel_list: np.ndarray, metric: str, knn: int,
     knn_graph.init_index(max_elements=num_elements, ef_construction=accuracy,
                          M=connections)
     knn_graph.add_items(pixel_list, num_threads=num_threads)
-    indices, distances = knn_graph.knn_query(pixel_list, k=knn,
+    indices, distances = knn_graph.knn_query(pixel_list, k=int(knn),
                                              num_threads=num_threads)
+    # import faiss  # make faiss available
+    # index = faiss.IndexFlatL2(dim)
+    # pixel_list = np.ascontiguousarray(pixel_list.astype('float32'))
+    # index.add(pixel_list)  # add vectors to the index
+    # distances, indices = index.search(pixel_list, knn)
+    # distances = np.power(distances,2)
+
     # lazy random walk means it returns distance of zero for same point
     # nbrs = LSHForest(n_estimators=20, n_candidates=200,
     #                  n_neighbors=10).fit(pixel_list)
     # distances, indices = nbrs.kneighbors(pixel_list)
+
+    # from annoy import AnnoyIndex
+    # t = AnnoyIndex(dim, 'dot')  # Length of item vector that will be indexed
+    # for num,x in enumerate(pixel_list):
+    #     t.add_item(num,x)
+    # t.build(20)
+    # indices = np.zeros((num_elements, knn), dtype=int)
+    # distances = np.zeros((num_elements, knn))
+    # for num in range(num_elements):
+    #     indice, distance = t.get_nns_by_item(num, knn, search_k=-1, include_distances=True)
+    #     indices[num] = indice
+    #     distances[num] = distance
+    # distances = np.power(distances,2)
+    # indices = io.loadmat('/Users/sschickler/Code_Devel/LSSC-python/inputs/nf_0200_indices.mat')['Inds'].transpose((1, 0))-1
+    # distances = io.loadmat('/Users/sschickler/Code_Devel/LSSC-python/inputs/nf_0200_distances.mat')['Dis'].transpose((1, 0))
+    # print("Lodaed mat files")
+    # print(indices.shape)
+    # print(distances.shape)
+    # print(num_elements)
     # TODO add comments here
-    reformat_indicies_x = np.repeat(np.arange(0, num_elements, 1), knn-1)
-    reformat_indicies_y = np.reshape(indices[:,1:], (-1))
-    reformat_distances = np.reshape(distances[:,1:], (-1))
+    reformat_indicies_x = np.repeat(np.arange(0, num_elements, 1), knn)
+    reformat_indicies_y = np.reshape(indices[:, 0:knn], (-1))
+    reformat_distances = np.reshape(distances[:, 0:knn], (-1))
+
     # Self tuning adaptive bandwidth
-    scale_factor_indices = np.repeat(distances[:, normalize_w_k], knn)
+    scale_factor_indices = np.repeat(distances[:, normalize_w_k], knn) + .000000001
     scale_factor_2_per_distances = np.power(scale_factor_indices[reformat_indicies_x],
                                             .5) * \
                                    np.power(scale_factor_indices[reformat_indicies_y],
@@ -63,13 +92,33 @@ def calcAffinityMatrix(*, pixel_list: np.ndarray, metric: str, knn: int,
     reformat_distances_scaled = np.exp(
         -reformat_distances / scale_factor_2_per_distances)
     # TODO change to go direct to csr matrix
-    return sparse.csr_matrix(sparse.coo_matrix(
+    reformat_distances_scaled[reformat_indicies_x == reformat_indicies_y] = 0
+    K = sparse.csr_matrix(
         (
-            np.hstack([reformat_distances_scaled,np.ones((num_elements))]),
-            (np.hstack([reformat_indicies_x,np.arange(0, num_elements, 1)]),np.hstack( [reformat_indicies_y,np.arange(0, num_elements, 1)]))),
-        shape=(num_elements, num_elements)))
+            reformat_distances_scaled,
+            (reformat_indicies_x,
+             reformat_indicies_y)),
+        shape=(num_elements, num_elements))
+    K_sym = (K + K.transpose()) / 2
+    # K_sym[np.arange(0, num_elements, 1),np.arange(0, num_elements, 1)] = 0
+    # save_image(K_sym.todense(),0)
+    print(str(temporal_box_num)+" "+str(spatial_box_num) + "  " + str(
+        np.count_nonzero(K_sym.diagonal()) / K_sym.diagonal().shape[0]))
+    return K_sym
 
 
+def save_image(image, num):
+    print(image.diagonal())
+    plt.imshow(
+        image, aspect="auto")
+    plt.colorbar()
+    path = os.path.join("/Users/sschickler/Code_Devel/LSSC-python/input_images/test",
+                        "eigen{}.png".format(
+                            num))
+    plt.savefig(path, dpi=300)
+    plt.close()
+    # image
+    # img.save(image_path)
 def calcDInv(K: sparse.csr_matrix):
     """Calculates a scaling diagonal matrix D to rescale eigen vectors
 
@@ -82,12 +131,14 @@ def calcDInv(K: sparse.csr_matrix):
     a sparse matrix with type csr, and D's diagonal values
     """
     dim = K.shape[0]
-    D_diag = np.nan_to_num(1/K.sum(axis=1), nan=0.000001, posinf =0.0000001, neginf=0.0000001) #add small epsilon to each row in K.sum()
+    D_diag_inv = 1 / (
+                K.sum(axis=1) + .000000001)  # add small epsilon to each row in K.sum()
+
     # D_diag = 1 / K.sum(axis=1)
     # print("D_diag",D_diag)
-    D_sparse = sparse.dia_matrix((np.reshape(D_diag, [1, -1]), [0]),
+    D_sparse = sparse.dia_matrix((np.reshape(D_diag_inv, [1, -1]), [0]),
                                  (dim, dim))
-    return sparse.csr_matrix(D_sparse), D_diag
+    return sparse.csr_matrix(D_sparse), (K.sum(axis=1) + .000000001)
 
 
 def calcLaplacian(P_sparse: sparse.csr_matrix, dim: Tuple[int, int]):
